<?php
/**
 * About Section options
 *
 * @package Theme Palace
 * @subpackage Chrisporate Pro
 * @since Chrisporate Pro 1.0.0
 */

// Add About section
$wp_customize->add_section( 'chrisporate_pro_about_section', array(
	'title'             => esc_html__( 'About Section','chrisporate-pro' ),
	'description'       => esc_html__( 'About Section options.', 'chrisporate-pro' ),
	'panel'             => 'chrisporate_pro_front_page_panel',
) );

// About content enable control and setting
$wp_customize->add_setting( 'chrisporate_pro_theme_options[about_section_enable]', array(
	'default'			=> 	$options['about_section_enable'],
	'sanitize_callback' => 'chrisporate_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Chrisporate_Pro_Switch_Control( $wp_customize, 'chrisporate_pro_theme_options[about_section_enable]', array(
	'label'             => esc_html__( 'About Section Enable', 'chrisporate-pro' ),
	'section'           => 'chrisporate_pro_about_section',
	'on_off_label' 		=> chrisporate_pro_switch_options(),
) ) );

// About us content type control and setting
$wp_customize->add_setting( 'chrisporate_pro_theme_options[about_content_type]', array(
	'default'          	=> $options['about_content_type'],
	'sanitize_callback' => 'chrisporate_pro_sanitize_select',
) );

$wp_customize->add_control( 'chrisporate_pro_theme_options[about_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'chrisporate-pro' ),
	'section'           => 'chrisporate_pro_about_section',
	'type'				=> 'select',
	'active_callback' 	=> 'chrisporate_pro_is_about_section_enable',
	'choices'			=> array( 
		'demo' 		=> esc_html__( 'Demo', 'chrisporate-pro' ),
		'custom' 	=> esc_html__( 'Custom', 'chrisporate-pro' ),
		'page' 		=> esc_html__( 'Page', 'chrisporate-pro' ),
		'post' 		=> esc_html__( 'Post', 'chrisporate-pro' ),
	),
) );

// Show page drop-down setting and control
$wp_customize->add_setting( 'chrisporate_pro_theme_options[about_content_page]', array(
	'sanitize_callback' => 'chrisporate_pro_sanitize_page'
) );

$wp_customize->add_control( 'chrisporate_pro_theme_options[about_content_page]', array(
	'label'           	=> esc_html__( 'Select Page', 'chrisporate-pro' ),
	'section'        	=> 'chrisporate_pro_about_section',
	'active_callback' 	=> 'chrisporate_pro_is_about_section_content_page_enable',
	'type'				=> 'dropdown-pages'
) );

// About us Section content type post setting and control.
$wp_customize->add_setting( 'chrisporate_pro_theme_options[about_content_post]', array(
	'validate_callback' => 'chrisporate_pro_validate_post_id',
	'sanitize_callback' => 'chrisporate_pro_sanitize_single_post_id',
) );

$wp_customize->add_control( 'chrisporate_pro_theme_options[about_content_post]', array(
	'active_callback'	=> 'chrisporate_pro_is_about_section_content_post_enable',
	'label'             => esc_html__( 'Input Post Id', 'chrisporate-pro' ),
	'description'       => esc_html__( 'Please Input Valid Post Id. Simply hover post title on dashboard to see the Post ID.', 'chrisporate-pro' ),
	'section'           => 'chrisporate_pro_about_section',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'style'	=> 'width:100px',
		),
) );

// About us title setting and control
$wp_customize->add_setting( 'chrisporate_pro_theme_options[about_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'          	=> $options['about_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'chrisporate_pro_theme_options[about_title]', array(
	'label'           	=> esc_html__( 'Title', 'chrisporate-pro' ),
	'section'        	=> 'chrisporate_pro_about_section',
	'active_callback' 	=> 'chrisporate_pro_is_about_section_content_custom_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'chrisporate_pro_theme_options[about_title]', array(
		'selector'            => '#about .container .about-content-title .entry-header h2.entry-title',
		'settings'            => 'chrisporate_pro_theme_options[about_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'chrisporate_pro_about_title_partial',
    ) );
}

// About us description setting and control
$wp_customize->add_setting( 'chrisporate_pro_theme_options[about_description]', array(
	'sanitize_callback' => 'wp_kses_post',
	'default'          	=> $options['about_description'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'chrisporate_pro_theme_options[about_description]', array(
	'label'           	=> esc_html__( 'Description', 'chrisporate-pro' ),
	'section'        	=> 'chrisporate_pro_about_section',
	'active_callback' 	=> 'chrisporate_pro_is_about_section_content_custom_enable',
	'type'				=> 'textarea',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'chrisporate_pro_theme_options[about_description]', array(
		'selector'            => '#about .container .entry-content .entry-summary p',
		'settings'            => 'chrisporate_pro_theme_options[about_description]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'chrisporate_pro_about_description_partial',
    ) );
}

// About content enable control and setting
$wp_customize->add_setting( 'chrisporate_pro_theme_options[about_social_enable]', array(
	'sanitize_callback' => 'chrisporate_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Chrisporate_Pro_Switch_Control( $wp_customize, 'chrisporate_pro_theme_options[about_social_enable]', array(
	'label'             => esc_html__( 'Enable Social Links', 'chrisporate-pro' ),
	'description'       => sprintf( '%1$s <a href="' . admin_url( '/customize.php?autofocus[panel]=nav_menus' ) . '"> %2$s </a> %3$s', esc_html__( 'Note: Create social menu to show social links.', 'chrisporate-pro' ), esc_html__( 'Click Here', 'chrisporate-pro' ), esc_html__( 'to create menu', 'chrisporate-pro' ) ),
	'section'           => 'chrisporate_pro_about_section',
	'on_off_label' 		=> chrisporate_pro_switch_options(),
	'active_callback' 	=> 'chrisporate_pro_is_about_section_enable',
) ) );

// About content enable control and setting
$wp_customize->add_setting( 'chrisporate_pro_theme_options[about_skills_enable]', array(
	'sanitize_callback' => 'chrisporate_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Chrisporate_Pro_Switch_Control( $wp_customize, 'chrisporate_pro_theme_options[about_skills_enable]', array(
	'label'             => esc_html__( 'Enable Skills', 'chrisporate-pro' ),
	'description'       => sprintf( '%1$s <a href="' . esc_url( 'https://wordpress.org/plugins/tp-piebuilder/' ) . '" target="_blank"> %2$s </a> %3$s', esc_html__( 'Show your skills in horizontal line graph. Use shortcode from TP PieBuilder plugin. ', 'chrisporate-pro' ), esc_html__( 'Click Here', 'chrisporate-pro' ), esc_html__( 'to download.', 'chrisporate-pro' ) ),
	'section'           => 'chrisporate_pro_about_section',
	'on_off_label' 		=> chrisporate_pro_switch_options(),
	'active_callback' 	=> 'chrisporate_pro_is_about_section_enable',
) ) );

// About us title setting and control
$wp_customize->add_setting( 'chrisporate_pro_theme_options[about_graph]', array(
	'default' 			=> $options['about_graph'],
	'sanitize_callback' => 'sanitize_textarea_field',
) );

$wp_customize->add_control( 'chrisporate_pro_theme_options[about_graph]', array(
	'label'           	=> esc_html__( 'Shortcode', 'chrisporate-pro' ),
	'section'        	=> 'chrisporate_pro_about_section',
	'active_callback' 	=> 'chrisporate_pro_is_about_section_skills_enable',
	'type'				=> 'textarea',
) );