<?php
/**
 * Counter Section options
 *
 * @package Theme Palace
 * @subpackage Chrisporate Pro
 * @since Chrisporate Pro 1.0.0
 */

// Add Counter section
$wp_customize->add_section( 'chrisporate_pro_counter_section', array(
	'title'             => esc_html__( 'Counter Section','chrisporate-pro' ),
	'description'       => esc_html__( 'Note: Background Video/Image is updated from Header Media Panel.', 'chrisporate-pro' ),
	'panel'             => 'chrisporate_pro_front_page_panel',
) );

// Featured Counter content enable control and setting
$wp_customize->add_setting( 'chrisporate_pro_theme_options[counter_section_enable]', array(
	'default'			=> 	$options['counter_section_enable'],
	'sanitize_callback' => 'chrisporate_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Chrisporate_Pro_Switch_Control( $wp_customize, 'chrisporate_pro_theme_options[counter_section_enable]', array(
	'label'             => esc_html__( 'Counter Section Enable', 'chrisporate-pro' ),
	'section'           => 'chrisporate_pro_counter_section',
	'on_off_label' 		=> chrisporate_pro_switch_options(),
) ) );

// Counter additional image setting and control.
$wp_customize->add_setting( 'chrisporate_pro_theme_options[counter_background_image]', array(
	'default' 			=> $options['counter_background_image'],
	'sanitize_callback' => 'chrisporate_pro_sanitize_image',
) );

$wp_customize->add_control(
	new WP_Customize_Image_Control( $wp_customize, 'chrisporate_pro_theme_options[counter_background_image]',
		array(
		'label'       		=> esc_html__( 'Select background Image', 'chrisporate-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'chrisporate-pro' ), 1920, 1000 ),
		'section'     		=> 'chrisporate_pro_counter_section',
		'active_callback'	=> 'chrisporate_pro_is_counter_section_enable',
) ) );

// Counter content type control and setting
$wp_customize->add_setting( 'chrisporate_pro_theme_options[counter_content_type]', array(
	'default'          	=> $options['counter_content_type'],
	'sanitize_callback' => 'chrisporate_pro_sanitize_select',
) );

$wp_customize->add_control( 'chrisporate_pro_theme_options[counter_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'chrisporate-pro' ),
	'section'           => 'chrisporate_pro_counter_section',
	'type'				=> 'select',
	'active_callback' 	=> 'chrisporate_pro_is_counter_section_enable',
	'choices'			=> array( 
		'demo' 		=> esc_html__( 'Demo', 'chrisporate-pro' ),
		'custom' 	=> esc_html__( 'Custom', 'chrisporate-pro' ),
	),
) );

// Counter number control and setting
$wp_customize->add_setting( 'chrisporate_pro_theme_options[counter_count]', array(
	'default'          	=> $options['counter_count'],
	'sanitize_callback' => 'chrisporate_pro_sanitize_number_range',
	'validate_callback' => 'chrisporate_pro_validate_counter_count',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'chrisporate_pro_theme_options[counter_count]', array(
	'label'             => esc_html__( 'Number of Counters', 'chrisporate-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 4. Please input the valid number and save. Then refresh the page to see the change.', 'chrisporate-pro' ),
	'section'           => 'chrisporate_pro_counter_section',
	'active_callback'   => 'chrisporate_pro_is_counter_section_content_custom_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 4,
		'style' => 'width: 100px;'
		),
) );

for ( $i = 1; $i <= $options['counter_count']; $i++ ) {
	// Counter hr setting and control
	$wp_customize->add_setting( 'chrisporate_pro_theme_options[service_section_hr_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Chrisporate_Pro_Customize_Horizontal_Line( $wp_customize, 'chrisporate_pro_theme_options[service_section_hr_' . $i . ']',
		array(
			'section'         => 'chrisporate_pro_counter_section',
			'active_callback' => 'chrisporate_pro_is_counter_section_content_custom_enable',
			'type'			  => 'hr'
	) ) );

	// Icon setting and control
	$wp_customize->add_setting( 'chrisporate_pro_theme_options[counter_section_icon_' . $i . ']', array(
		'default' 			=> $options['counter_section_icon'],
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'chrisporate_pro_theme_options[counter_section_icon_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Icon %d', 'chrisporate-pro' ), $i ),
		'description'     	=> sprintf( '%1$s <a target="_blank" href="' . esc_url( 'http://fontawesome.io/icons/' ) . '"> %2$s </a>', esc_html__( 'Select Icon ie: fa-check. See more at ', 'chrisporate-pro' ), esc_html__( 'Font awesome', 'chrisporate-pro' ) ),
		'section'        	=> 'chrisporate_pro_counter_section',
		'type'				=> 'text',
		'active_callback'	=> 'chrisporate_pro_is_counter_section_content_custom_enable',
	) );

	// title setting and control
	$wp_customize->add_setting( 'chrisporate_pro_theme_options[counter_section_title_' . $i . ']', array(
		'default' 			=> $options['counter_section_title'],
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'chrisporate_pro_theme_options[counter_section_title_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Title %d', 'chrisporate-pro' ), $i ),
		'section'        	=> 'chrisporate_pro_counter_section',
		'type'				=> 'text',
		'active_callback'	=> 'chrisporate_pro_is_counter_section_content_custom_enable',
	) );

	// Counter value control and setting
	$wp_customize->add_setting( 'chrisporate_pro_theme_options[counter_section_value_' . $i . ']', array(
		'default'          	=> $options['counter_section_value'],
		'sanitize_callback' => 'chrisporate_pro_sanitize_number_range',
		'transport'			=> 'postMessage',
	) );

	$wp_customize->add_control( 'chrisporate_pro_theme_options[counter_section_value_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Value %d', 'chrisporate-pro' ), $i ),
		'section'           => 'chrisporate_pro_counter_section',
		'active_callback'   => 'chrisporate_pro_is_counter_section_content_custom_enable',
		'type'				=> 'number',
		'input_attrs'		=> array(
			'style' => 'width: 100px;'
			),
	) );
}
