<?php
/**
 * Custom functions that act independently of the theme templates.
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package Theme Palace
 * @subpackage Chrisporate Pro
 * @since Chrisporate Pro 1.0.0
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function chrisporate_pro_body_classes( $classes ) {
	$options = chrisporate_pro_get_theme_options();

	// Adds a class of group-blog to blogs with more than 1 published author.
	if ( is_multi_author() ) {
		$classes[] = 'group-blog';
	}

	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}

	// Add a class for typography
	$typography = (  $options['theme_typography'] == 'default' ) ? '' :  $options['theme_typography'];
	$classes[] = esc_attr( $typography );

	$body_typography = (  $options['body_theme_typography'] == 'default' ) ? '' :  $options['body_theme_typography'];
	$classes[] = esc_attr( $body_typography );

	// Add a class for layout
	$classes[] = esc_attr( $options['site_layout'] );

	// home page side icon menu
	$classes[] = ( true === $options['side_menu'] ) ? 'icon-navigation-enabled' : '';

	// Add a class for sidebar
	$sidebar_position = chrisporate_pro_layout();
	$sidebar = is_singular() ? get_post_meta( get_the_id(), 'chrisporate-pro-selected-sidebar', true ) : 'sidebar-1';
	if ( is_active_sidebar( $sidebar ) ) {
		$classes[] = esc_attr( $sidebar_position );
	} else {
		$classes[] = 'no-sidebar';
	}

	$colors = esc_attr( $options['colorscheme'] );
	$classes[] = 'colors-' . $colors;

	return $classes;
}
add_filter( 'body_class', 'chrisporate_pro_body_classes' );
