<?php
/**
 * Author section
 *
 * This is the template for the content of author section
 *
 * @package Theme Palace
 * @subpackage Chrisporate Pro
 * @since Chrisporate Pro 1.0.0
 */
if ( ! function_exists( 'chrisporate_pro_add_author_section' ) ) :
    /**
    * Add author section
    *
    *@since Chrisporate Pro 1.0.0
    */
    function chrisporate_pro_add_author_section() {
    	$options = chrisporate_pro_get_theme_options();
        // Check if author is enabled on frontpage
        $author_enable = apply_filters( 'chrisporate_pro_section_status', true, 'author_section_enable' );

        if ( true !== $author_enable ) {
            return false;
        }
        // Get author section details
        $section_details = array();
        $section_details = apply_filters( 'chrisporate_pro_filter_author_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render author section now.
        chrisporate_pro_render_author_section( $section_details );
    }
endif;


if ( ! function_exists( 'chrisporate_pro_get_author_section_details' ) ) :
    /**
    * author section details.
    *
    * @since Chrisporate Pro 1.0.0
    * @param array $input author section details.
    */
    function chrisporate_pro_get_author_section_details( $input ) {
        $options = chrisporate_pro_get_theme_options();

        // Content type.
        $author_content_type   = $options['author_content_type'];
        $author_count          = ! empty( $options['author_count'] ) ? $options['author_count'] : 2;
        $content = array();

        switch ( $author_content_type ) {
            case 'demo':
                $title = array(
                    1 => esc_html__( 'Melina Newman', 'chrisporate-pro' ),
                    2 => esc_html__( 'Arina Kidman', 'chrisporate-pro' ),
                    );
                $sub_title = array(
                    1 => esc_html__( 'UI/UX Designer', 'chrisporate-pro' ),
                    2 => esc_html__( 'Web Developer', 'chrisporate-pro' ),
                    );
                $social = array(
                    1 => esc_url_raw( 'facebook.com' ),
                    2 => esc_url_raw( 'twitter.com' ),
                    3 => esc_url_raw( 'youtube.com' ),
                    );
                for ( $i = 1; $i <= 2; $i++ ) {
                    $demo['image']        = get_template_directory_uri() . '/assets/uploads/author-slider.png';
                    $demo['title']        = $title[$i];
                    $demo['sub_title']    = $sub_title[$i];
                    $demo['excerpt']      = esc_html__( 'Mauris ut metus a nibh fermentum mollis. Cras ullamcorper ac lectus eget hendrerit. Aenean lacinia volutpat blandit. In ultricies iaculis orci queleifend. Nunc in placerat odio. Nullam porta sapien ac nunc egestas aliquam. Nulla vitae pharetra enim. Sed sed consectetur nibh, vel placerat mauris. Mauris ut metus a nibh fermentum mollis. Cras ullamcorper ac lectus eget hendrerit. Aenean lacinia volutpat blandit. In ultricies iaculis orci queleifend. Nunc in placerat odio. Nullam porta sapien ac nunc egestas aliquam. Nulla vitae pharetra enim. Sed sed consectetur nibh, vel placerat mauris.', 'chrisporate-pro' );
                    $demo['social']        = $social; 
                   
                    // Push to the main array.
                    array_push( $content, $demo );
                }

            break;

            case 'custom':
                for ( $i = 1; $i <= $author_count; $i++ ) {
                    $custom['image']        = isset( $options['author_image_' . $i] ) ? $options['author_image_' . $i] : $options['author_image'];
                    $custom['title']        = isset( $options['author_title_' . $i] ) ? $options['author_title_' . $i] : $options['author_title'];
                    $custom['sub_title']    = isset( $options['author_sub_title_' . $i] ) ? $options['author_sub_title_' . $i] : $options['author_sub_title'];
                    $custom['excerpt']      = isset( $options['author_description_' . $i] ) ? $options['author_description_' . $i] : $options['author_description'];
                    $custom['social']       = isset( $options['author_social_' . $i] ) ? explode( '|' , $options['author_social_' . $i] ) : array( $options['author_social'] ); 
                   
                    // Push to the main array.
                    array_push( $content, $custom );
                }
            break;

            case 'category':
                $cat_id = ! empty( $options['author_content_category'] ) ? $options['author_content_category'] : '';

                $args = array(
                    'post_type'         => 'post',
                    'cat'               => $cat_id,
                    'posts_per_page'    => $author_count,
                    );
            break;

            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $author_count; $i++ ) {
                    if ( ! empty( $options['author_content_page_' . $i] ) )
                        $page_ids[] = $options['author_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => $author_count,
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = ! empty( $options['author_content_post'] ) ? $options['author_content_post'] : array();
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => count( $post_ids ),
                    'orderby'           => 'post__in',
                    );
            break;

            default:
            break;
        }

        if ( in_array( $author_content_type, array( 'page', 'post', 'category' ) ) ) {

            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['image']       = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'large' ) : '';
                    $page_post['title']       = get_the_title();
                    $page_post['sub_title']   = '';
                    $page_post['url']         = get_the_permalink();
                    $page_post['excerpt']     = get_the_content();
                    $page_post['social']      = array();

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();

        }
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// author section content details.
add_filter( 'chrisporate_pro_filter_author_section_details', 'chrisporate_pro_get_author_section_details' );


if ( ! function_exists( 'chrisporate_pro_render_author_section' ) ) :
  /**
   * Start author section
   *
   * @return string author content
   * @since Chrisporate Pro 1.0.0
   *
   */
   function chrisporate_pro_render_author_section( $content_details = array() ) {
        $options = chrisporate_pro_get_theme_options();

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="author" class="col-2 relative">
            <div class="container">
                <div class="author-slider" data-slick='{"slidesToShow": 1, "slidesToScroll": 1, "infinite": false, "speed": 600, "dots": false, "arrows":true, "autoplay": true, "fade": true }'>
                    <?php foreach( $content_details as $content ) : ?>
                        <div class="slick-item <?php echo empty( $content['image'] ) ? 'no-featured-image' : ''; ?>">
                            <?php if ( ! empty( $content['image'] ) ) : ?>
                                <div class="hentry">
                                    <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');"></div>
                                </div><!-- .hentry -->
                            <?php endif; ?>

                            <div class="hentry">
                                <div class="author-slider-content">
                                    <header class="entry-header">
                                        <?php if ( ! empty( $content['title'] ) ) : ?>
                                            <h2 class="entry-title"><?php echo esc_html( $content['title'] ); ?></h2>
                                        <?php endif; 
                                        if ( ! empty( $content['sub_title'] ) ) : ?>
                                            <span><?php echo esc_html( $content['sub_title'] ); ?></span>
                                        <?php endif; ?>
                                    </header><!-- .entry-header -->

                                    <?php if ( ! empty( $content['excerpt'] ) ) : ?>
                                        <div class="entry-content">
                                            <p><?php echo wp_kses_post( $content['excerpt'] ); ?></p>
                                        </div><!-- .entry-content -->
                                    <?php endif; 
                                    if ( ! empty( $content['social'][0] ) ) : ?>
                                        <ul class="social-icons">
                                            <?php foreach ( $content['social'] as $social ) : ?>
                                                <li><a href="<?php echo esc_url( $social ); ?>"></a></li>
                                            <?php endforeach; ?>
                                        </ul><!-- .social-icons -->
                                    <?php endif; ?>
                                </div><!-- .author-slider-content -->
                            </div><!-- .hentry -->
                        </div><!-- .slick-item -->
                    <?php endforeach; ?>
                </div><!-- .author-slider -->
            </div><!-- .container -->
        </div><!-- #author -->
    <?php 
    }
endif;