<?php
/**
 * Client section
 *
 * This is the template for the content of client section
 *
 * @package Theme Palace
 * @subpackage Chrisporate Pro
 * @since Chrisporate Pro 1.0.0
 */
if ( ! function_exists( 'chrisporate_pro_add_client_section' ) ) :
    /**
    * Add client section
    *
    *@since Chrisporate Pro 1.0.0
    */
    function chrisporate_pro_add_client_section() {
    	$options = chrisporate_pro_get_theme_options();
        // Check if client is enabled on frontpage
        $client_enable = apply_filters( 'chrisporate_pro_section_status', true, 'client_section_enable' );

        if ( true !== $client_enable ) {
            return false;
        }
        // Get client section details
        $section_details = array();
        $section_details = apply_filters( 'chrisporate_pro_filter_client_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render client section now.
        chrisporate_pro_render_client_section( $section_details );
    }
endif;


if ( ! function_exists( 'chrisporate_pro_get_client_section_details' ) ) :
    /**
    * client section details.
    *
    * @since Chrisporate Pro 1.0.0
    * @param array $input client section details.
    */
    function chrisporate_pro_get_client_section_details( $input ) {
        $options = chrisporate_pro_get_theme_options();

        // Content type.
        $client_content_type   = $options['client_content_type'];
        $client_count          = ! empty( $options['client_count'] ) ? $options['client_count'] : 2;
        $content = array();

        switch ( $client_content_type ) {
            case 'demo':
                for ( $i = 1; $i <= 6; $i++ ) {
                    $demo['title']      = esc_html__( 'Company Name', 'chrisporate-pro' );
                    $demo['url']        = '#';
                    $demo['image']      = get_template_directory_uri() . '/assets/uploads/client-0'. $i . '.png';
                   
                    // Push to the main array.
                    array_push( $content, $demo );
                }

            break;

            case 'custom':
                for ( $i = 1; $i <= $client_count; $i++ ) {
                    $custom['title']    = isset( $options['client_title_' . $i] ) ? $options['client_title_' . $i] : $options['client_title'];
                    $custom['url']      = ! empty( $options['client_link_' . $i] ) ? $options['client_link_' . $i] : '#';
                    $custom['image']    = isset( $options['client_image_' . $i] ) ? $options['client_image_' . $i] : $options['client_image'];
                   
                    // Push to the main array.
                    array_push( $content, $custom );
                }
            break;

            case 'category':
                $cat_id = ! empty( $options['client_content_category'] ) ? $options['client_content_category'] : '';

                $args = array(
                    'post_type'         => 'post',
                    'cat'               => $cat_id,
                    'posts_per_page'    => $client_count,
                    );
            break;

            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $client_count; $i++ ) {
                    if ( ! empty( $options['client_content_page_' . $i] ) )
                        $page_ids[] = $options['client_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          =>  ( array ) $page_ids,
                    'posts_per_page'    => $client_count,
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = ! empty( $options['client_content_post'] ) ? $options['client_content_post'] : array();
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => count( $post_ids ),
                    'orderby'           => 'post__in',
                    );
            break;

            default:
            break;
        }

        if ( in_array( $client_content_type, array( 'page', 'post', 'category' ) ) ) {

            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['title']   = get_the_title();
                    $page_post['url']     = get_the_permalink();
                    $page_post['image']   = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : '';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();

        }
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// client section content details.
add_filter( 'chrisporate_pro_filter_client_section_details', 'chrisporate_pro_get_client_section_details' );


if ( ! function_exists( 'chrisporate_pro_render_client_section' ) ) :
  /**
   * Start client section
   *
   * @return string client content
   * @since Chrisporate Pro 1.0.0
   *
   */
   function chrisporate_pro_render_client_section( $content_details = array() ) {
        $options = chrisporate_pro_get_theme_options();
        $title  = ! empty( $options['client_section_title'] ) ? $options['client_section_title'] : '';
        $image  = ! empty( $options['client_background_image'] ) ? $options['client_background_image'] : get_template_directory_uri() . '/assets/uploads/client.jpg';

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="client" class="relative">
            <div class="container">
                <div class="regular" data-slick='{"slidesToShow": <?php echo  $options['client_count'];?>, "slidesToScroll": 1, "infinite": true, "speed": 300, "dots": false, "arrows":false, "autoplay": true, "fade": false, "draggable":true}'>
                <?php foreach ( $content_details as $content ) : 
                    if ( ! empty( $content['image'] ) ) : ?>
                        <div class="client-slider">
                            <a href="<?php echo esc_url( $content['url'] ); ?>">
                                <img src="<?php echo esc_url( $content['image'] ) ?>" title="<?php echo esc_attr( $content['title'] ); ?>" alt="<?php echo esc_attr( $content['title'] ); ?>">
                            </a>
                        </div><!--.client-slider-->
                    <?php endif; 
                endforeach; ?>
                </div><!-- .regular -->
            </div><!-- container -->
        </div><!-- client -->
    <?php 
    }
endif;