<?php
/**
 * Counter section
 *
 * This is the template for the content of counter section
 *
 * @package Theme Palace
 * @subpackage Chrisporate Pro
 * @since Chrisporate Pro 1.0.0
 */
if ( ! function_exists( 'chrisporate_pro_add_counter_section' ) ) :
    /**
    * Add counter section
    *
    *@since Chrisporate Pro 1.0.0
    */
    function chrisporate_pro_add_counter_section() {
    	$options = chrisporate_pro_get_theme_options();
        // Check if counter is enabled on frontpage
        $counter_enable = apply_filters( 'chrisporate_pro_section_status', true, 'counter_section_enable' );

        if ( true !== $counter_enable ) {
            return false;
        }
        // Get counter section details
        $section_details = array();
        $section_details = apply_filters( 'chrisporate_pro_filter_counter_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render counter section now.
        chrisporate_pro_render_counter_section( $section_details );
    }
endif;


if ( ! function_exists( 'chrisporate_pro_get_counter_section_details' ) ) :
    /**
    * counter section details.
    *
    * @since Chrisporate Pro 1.0.0
    * @param array $input counter section details.
    */
    function chrisporate_pro_get_counter_section_details( $input ) {
        $options = chrisporate_pro_get_theme_options();

        // Content type.
        $counter_content_type  = $options['counter_content_type'];
        $counter_count = ! empty( $options['counter_count'] ) ? $options['counter_count'] : 4;
        $content = array();
        switch ( $counter_content_type ) {
            case 'demo':
                $icon = array(
                    1 => 'fa-pencil-square-o',
                    2 => 'fa-keyboard-o',
                    3 => 'fa-picture-o',
                    4 => 'fa-users',
                    );
                $title = array(
                    1 => esc_html__( 'Design', 'chrisporate-pro' ),
                    2 => esc_html__( 'Development', 'chrisporate-pro' ),
                    3 => esc_html__( 'Photography', 'chrisporate-pro' ),
                    4 => esc_html__( 'Happy Customers', 'chrisporate-pro' ),
                    );
                $value = array(
                    1 => 526,
                    2 => 269,
                    3 => 817,
                    4 => 2500,
                    );
                for ( $i = 1; $i <= 4; $i++ ) {
                    $demo['icon']       = $icon[$i];
                    $demo['title']      = $title[$i];
                    $demo['value']      = $value[$i];
                    
                    // Push to the main array.
                    array_push( $content, $demo );
                }
            break;

            case 'custom':
                for ( $i = 1; $i <= $counter_count; $i++ ) {
                    $custom['icon']     = isset( $options['counter_section_icon_' . $i] ) ? $options['counter_section_icon_' . $i] : $options['counter_section_icon'];
                    $custom['title']    = isset( $options['counter_section_title_' . $i] ) ? $options['counter_section_title_' . $i] : $options['counter_section_title'];
                    $custom['value']    = isset( $options['counter_section_value_' . $i] ) ? $options['counter_section_value_' . $i] : $options['counter_section_value'];

                    // Push to the main array.
                    array_push( $content, $custom );
                }
            break;

            default:
            break;
        }
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// counter section content details.
add_filter( 'chrisporate_pro_filter_counter_section_details', 'chrisporate_pro_get_counter_section_details' );


if ( ! function_exists( 'chrisporate_pro_render_counter_section' ) ) :
  /**
   * Start counter section
   *
   * @return string counter content
   * @since Chrisporate Pro 1.0.0
   *
   */
   function chrisporate_pro_render_counter_section( $content_details = array() ) {
        $options = chrisporate_pro_get_theme_options();
        $background = ! empty( $options['counter_background_image'] ) ? $options['counter_background_image'] : get_template_directory_uri() . '/assets/uploads/counter.jpg';

        if ( empty( $content_details ) ) {
            return;
        } ?>

            <div id="counter" class="page-section relative col-<?php echo  $options['counter_count'];?>" style="background-image: url('<?php echo esc_url( $background ); ?>')">
            <div class="overlay"></div>
            <div class="container">
                <?php foreach ( $content_details as $content ) : ?>
                    <div class="hentry">
                        <div class="statwrap">
                            <i class="fa <?php echo esc_attr( $content['icon'] ); ?>"></i>
                            <h1 class="stat-count"><?php echo absint( $content['value'] ); ?></h1>
                            <small><?php echo esc_html( $content['title'] ); ?></small>
                        </div><!-- .statwrap -->
                    </div><!-- .hentry -->
                <?php endforeach; ?>
            </div><!-- .container -->
        </div><!-- #counter -->

    <?php   
    }
endif;