<?php
/**
 * Latest Blog section
 *
 * This is the template for the content of latest blog section
 *
 * @package Theme Palace
 * @subpackage Chrisporate Pro
 * @since Chrisporate Pro 1.0.0
 */
if ( ! function_exists( 'chrisporate_pro_add_latest_blog_section' ) ) :
    /**
    * Add latest blog section
    *
    *@since Chrisporate Pro 1.0.0
    */
    function chrisporate_pro_add_latest_blog_section() {
    	$options = chrisporate_pro_get_theme_options();
        // Check if latest-blog is enabled on frontpage
        $latest_blog_enable = apply_filters( 'chrisporate_pro_section_status', true, 'latest_blog_section_enable' );

        if ( true !== $latest_blog_enable ) {
            return false;
        }
        // Get latest blog section details
        $section_details = array();
        $section_details = apply_filters( 'chrisporate_pro_filter_latest_blog_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render latest blog section now.
        chrisporate_pro_render_latest_blog_section( $section_details );
    }
endif;


if ( ! function_exists( 'chrisporate_pro_get_latest_blog_section_details' ) ) :
    /**
    * latest blog section details.
    *
    * @since Chrisporate Pro 1.0.0
    * @param array $input latest blog section details.
    */
    function chrisporate_pro_get_latest_blog_section_details( $input ) {
        $options = chrisporate_pro_get_theme_options();

        // Content type.
        $latest_blog_title_type     = $options['latest_blog_title_type'];
        $latest_blog_content_type   = $options['latest_blog_content_type'];
        $latest_blog_count          = ! empty( $options['latest_blog_count'] ) ? $options['latest_blog_count'] : 3;
        $content = array();
        $content['heading'] = array();
        $content['detail'] = array();
        switch ( $latest_blog_title_type ) {
            case 'demo':
                $demo['heading']['title']      = esc_html__( 'Latest Blog', 'chrisporate-pro' );
                $demo['heading']['excerpt']    = esc_html__( 'Cras placerat ipsum sit amet vehicula rhoncus. Aenean blandit leo mauris, ut lobortis diam egestas et. Pellentesque lorem massa, pharetra non dolor eu, pharetra maximus mi. Maecenas et condimentum erat. Donec consectetur neque justo, in faucibus nunc tristique sit amet.', 'chrisporate-pro' );

                // Push to the main array.
                array_push( $content['heading'], $demo['heading'] );
            break;

            case 'custom':
                $custom['heading']['title']        = ! empty( $options['latest_blog_title'] ) ? $options['latest_blog_title'] : '';
                $custom['heading']['excerpt']      = ! empty( $options['latest_blog_description'] ) ? $options['latest_blog_description'] : '';

                // Push to the main array.
                array_push( $content['heading'], $custom['heading'] );
            break;

            case 'page':
                $page_id = ! empty( $options['latest_blog_title_page'] ) ? $options['latest_blog_title_page'] : '';
                $args = array(
                    'post_type'         => 'page',
                    'page_id'           => $page_id,
                    'posts_per_page'    => 1,
                    );                    
            break;

            case 'post':
                $post_id = ! empty( $options['latest_blog_title_post'] ) ? $options['latest_blog_title_post'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'p'                 => $post_id,
                    'posts_per_page'    => 1,
                    );
            break;

            default:
            break;
        }

        if ( 'post' === $latest_blog_title_type || 'page' === $latest_blog_title_type ) {

            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['heading']['title']     = get_the_title();
                    $page_post['heading']['excerpt']   = get_the_content();

                    // Push to the main array.
                    array_push( $content['heading'], $page_post['heading'] );
                endwhile;
            endif;
            wp_reset_postdata();

        }

        switch ( $latest_blog_content_type ) {
            case 'demo':
                $title = array(
                    1 => esc_html__( 'Grey bg & green plant', 'chrisporate-pro' ),
                    2 => esc_html__( 'Perfect Photo frame', 'chrisporate-pro' ),
                    3 => esc_html__( 'Skyscraper Buildings', 'chrisporate-pro' ),
                    );
                for ( $i = 1; $i <= 3; $i++ ) {
                    $demo['detail']['image']        = get_template_directory_uri() . '/assets/uploads/blog-0' . $i . '.jpg';
                    $demo['detail']['title']        = $title[$i];
                    $demo['detail']['url']          = '#';
                    $demo['detail']['author']       =  esc_html__( 'Author', 'chrisporate-pro' );
                    $demo['detail']['excerpt']      = esc_html__( 'Mauris ut metus a nibh fermentum mollis. Cras ullamcorper ac lectus eget hendrerit. Aenean lacinia volutpat blandit. In ultricies iaculis orci...', 'chrisporate-pro' );
                   
                    // Push to the main array.
                    array_push( $content['detail'], $demo['detail'] );
                }

            break;

            case 'category':
                $cat_id = ! empty( $options['latest_blog_content_category'] ) ? $options['latest_blog_content_category'] : '';

                $args = array(
                    'post_type'         => 'post',
                    'cat'               => $cat_id,
                    'posts_per_page'    => $latest_blog_count,
                    );
            break;

            case 'all':
                $cat_ids = ! empty( $options['latest_blog_exclude_category'] ) ? $options['latest_blog_exclude_category'] : array();
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => $latest_blog_count,
                    'category__not_in'  => ( array ) $cat_ids,
                    'ignore_sticky_posts'   => true,
                    );
            break;

            default:
            break;
        }

        if ( in_array( $latest_blog_content_type, array( 'all', 'category' ) ) ) {

            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['detail']['image']       = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-550x382.jpg';
                    $page_post['detail']['id']          = get_the_id();
                    $page_post['detail']['title']       = get_the_title();
                    $page_post['detail']['url']         = get_the_permalink();
                    $page_post['detail']['excerpt']     = chrisporate_pro_trim_content( 20 );
                    $page_post['detail']['author']      = get_the_author_posts_link();

                    // Push to the main array.
                    array_push( $content['detail'], $page_post['detail'] );
                endwhile;
            endif;
            wp_reset_postdata();

        }
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// latest blog section content details.
add_filter( 'chrisporate_pro_filter_latest_blog_section_details', 'chrisporate_pro_get_latest_blog_section_details' );


if ( ! function_exists( 'chrisporate_pro_render_latest_blog_section' ) ) :
  /**
   * Start latest blog section
   *
   * @return string latest-blog content
   * @since Chrisporate Pro 1.0.0
   *
   */
   function chrisporate_pro_render_latest_blog_section( $content_details = array() ) {
        $options = chrisporate_pro_get_theme_options();
        $read_more = ! empty( $options['read_more_text'] ) ? $options['read_more_text'] : esc_html__( 'Read More', 'chrisporate-pro' );
        $latest_blog_content_type   = $options['latest_blog_content_type'];
        $column = ! empty( $options['latest_blog_section_layout'] ) ? $options['latest_blog_section_layout'] : 'col-3';

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="latest-blog" class="page-section relative">
            <div class="container">
             <?php foreach ( $content_details['heading'] as $content ) : ?>
                    <div class="latest-content-title clear">
                        <?php if ( ! empty( $content['title'] ) ) : ?>
                            <header class="entry-header section-title">
                                <h2 class="entry-title"><?php echo esc_html( $content['title'] ); ?></h2>
                            </header><!-- .entry-header -->
                        <?php endif; 

                        if ( ! empty( $content['excerpt'] ) ) : ?>
                            <p class="description"><?php echo wp_kses_post( $content['excerpt'] ); ?></p>
                        <?php endif; ?>
                    </div><!-- .latest-blog-contennt -->
                <?php endforeach; ?>

                <div class="blog-posts-wrapper <?php echo esc_attr( $column ); ?> clear">
                    <?php foreach ( $content_details['detail'] as $content ) : ?>
                        <article class="hentry">
                            <?php if ( ! empty( $content['image'] ) ) : ?>
                                <div class="featured-image">
                                    <a href="<?php echo esc_url( $content['url'] ); ?>"><img src="<?php echo esc_url( $content['image'] ); ?>" alt="<?php echo esc_attr( $content['title'] ); ?>"></a>
                                </div><!--.featured-image-->
                            <?php endif; ?>

                            <div class="entry-container">
                                <div class="entry-meta">
                                    <span class="cat-links">
                                        <?php if ( in_array( $latest_blog_content_type, array( 'all', 'category' ) ) ) :
                                            the_category( ', ', '', $content['id'] ); 
                                        else : ?>
                                            <a href="#"><?php esc_html_e( 'Category', 'chrisporate-pro' ); ?></a>
                                        <?php endif; ?>
                                    </span>
                                    <span class="byline"><?php esc_html_e( 'BY ', 'chrisporate-pro' ) ?>
                                        <span class="author vcard">
                                            <?php echo wp_kses_post( $content['author'] ); ?>
                                        </span>
                                    </span>
                                </div><!-- .entry-meta -->
                                <header class="entry-header">
                                    <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                </header>
                               
                                <div class="entry-content">
                                    <p><?php echo esc_html( $content['excerpt'] ); ?></p>

                                    <a href="<?php echo esc_url( $content['url'] ); ?>" class="btn btn-fill"><?php echo esc_html( $read_more ); ?></a>
                                </div><!--.blog-content-->
                            </div><!-- .entry-container -->
                        </article><!-- #post-1 -->
                    <?php endforeach; ?>
                </div><!-- .blog-wrapper -->

                <?php if ( in_array( $latest_blog_content_type, array( 'all', 'category' ) ) ) : 
                    if ( 'category' == $latest_blog_content_type ) :
                        $link = get_category_link( $options['latest_blog_content_category'] );
                    elseif ( 'all' == $latest_blog_content_type ) :
                        $link = get_the_permalink( get_option( 'page_for_posts' ) );
                    endif;
                    $btn_label = ! empty( $options['latest_blog_btn_label'] ) ? $options['latest_blog_btn_label'] : esc_html__( 'Load More Blog', 'chrisporate-pro' );
                    ?>
                    <div class="align-center">
                        <?php $icon = ! empty( $options['loader_icon'] ) ? $options['loader_icon'] : 'fa-circle-o-notch'; ?>
                        <div id="latest-blog-loader" class="home-ajax-loader hide"><i class="fa <?php echo esc_attr( $icon ); ?> fa-2x fa-spin"></i></div>

                        <a <?php echo ( 'ajax' == $options['latest_blog_load_more'] ) ? 'id="LBloadmore"' : ''; ?> href="<?php echo ( 'link' == $options['latest_blog_load_more'] ) ? esc_url( $link ) : '#'; ?>" class="load-more"><?php echo esc_html( $btn_label ); ?>
                            <i class="fa fa-angle-down"></i>
                        </a>
                    </div><!-- .align-center -->
                <?php endif; ?>

            </div><!-- .container -->
        </div><!-- #latest-blog -->
    <?php 
    }
endif;