<?php
/**
 * Services section
 *
 * This is the template for the content of service section
 *
 * @package Theme Palace
 * @subpackage Chrisporate Pro
 * @since Chrisporate Pro 1.0.0
 */
if ( ! function_exists( 'chrisporate_pro_add_service_section' ) ) :
    /**
    * Add service section
    *
    *@since Chrisporate Pro 1.0.0
    */
    function chrisporate_pro_add_service_section() {
    	$options = chrisporate_pro_get_theme_options();
        // Check if service is enabled on frontpage
        $service_enable = apply_filters( 'chrisporate_pro_section_status', true, 'service_section_enable' );

        if ( true !== $service_enable ) {
            return false;
        }
        // Get service section details
        $section_details = array();
        $section_details = apply_filters( 'chrisporate_pro_filter_service_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render service section now.
        chrisporate_pro_render_service_section( $section_details );
    }
endif;


if ( ! function_exists( 'chrisporate_pro_get_service_section_details' ) ) :
    /**
    * service section details.
    *
    * @since Chrisporate Pro 1.0.0
    * @param array $input service section details.
    */
    function chrisporate_pro_get_service_section_details( $input ) {
        $options = chrisporate_pro_get_theme_options();

        // Content type.
        $service_title_type     = $options['service_title_type'];
        $service_content_type   = $options['service_content_type'];
        $service_count          = ! empty( $options['service_count'] ) ? $options['service_count'] : 4;
        $content = array();
        $content['heading'] = array();
        $content['detail'] = array();
        switch ( $service_title_type ) {
            case 'demo':
                $demo['heading']['title']      = esc_html__( 'Services', 'chrisporate-pro' );
                $demo['heading']['excerpt']    = esc_html__( 'MCras placerat ipsum sit amet vehicula rhoncus. Aenean blandit leo mauris, ut lobortis diam egestas et. Pellentesque lorem massa, pharetra non dolor eu, pharetra maximus mi. Maecenas et condimentum erat. Donec consectetur neque justo, in faucibus nunc tristique sit amet.', 'chrisporate-pro' );

                // Push to the main array.
                array_push( $content['heading'], $demo['heading'] );
            break;

            case 'custom':
                $custom['heading']['title']        = ! empty( $options['service_title'] ) ? $options['service_title'] : '';
                $custom['heading']['excerpt']      = ! empty( $options['service_description'] ) ? $options['service_description'] : '';

                // Push to the main array.
                array_push( $content['heading'], $custom['heading'] );
            break;

            case 'page':
                $page_id = ! empty( $options['service_title_page'] ) ? $options['service_title_page'] : '';
                $args = array(
                    'post_type'         => 'page',
                    'page_id'           => $page_id,
                    'posts_per_page'    => 1,
                    );                    
            break;

            case 'post':
                $post_id = ! empty( $options['service_title_post'] ) ? $options['service_title_post'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'p'                 => $post_id,
                    'posts_per_page'    => 1,
                    );
            break;

            default:
            break;
        }

        if ( 'post' === $service_title_type || 'page' === $service_title_type ) {

            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['heading']['title']     = get_the_title();
                    $page_post['heading']['excerpt']   = get_the_content();

                    // Push to the main array.
                    array_push( $content['heading'], $page_post['heading'] );
                endwhile;
            endif;
            wp_reset_postdata();

        }

        switch ( $service_content_type ) {
            case 'demo':
                $icon = array(  
                    1 => 'fa-send-o',
                    2 => 'fa-television',
                    3 => 'fa-film',
                    4 => 'fa-camera-retro',
                    );
                $title = array(
                    1 => esc_html__( 'Branding', 'chrisporate-pro' ),
                    2 => esc_html__( 'Web Design', 'chrisporate-pro' ),
                    3 => esc_html__( 'multi media', 'chrisporate-pro' ),
                    4 => esc_html__( 'Photography', 'chrisporate-pro' ),
                    );
                for ( $i = 1; $i <= 4; $i++ ) {
                    $demo['detail']['icon']         = $icon[$i];
                    $demo['detail']['id']           = $i;
                    $demo['detail']['title']        = $title[$i];
                    $demo['detail']['sub_title']    = esc_html__( 'A brand is more than just a logo which communicates to your audience who your company is.', 'chrisporate-pro' );
                    $demo['detail']['excerpt']      = esc_html__( 'Mauris ut metus a nibh fermentum mollis. Cras ullamcorper ac lectus eget hendrerit. Aenean lacinia volutpat blandit. In ultricies iaculis orci queleifend. Nunc in placerat odio. Nullam porta sapien ac nunc egestas aliquam. Nulla vitae pharetra enim. Sed sed consectetur nibh, vel placerat mauris. Mauris ut metus a nibh fermentum mollis. Cras ullamcorper ac lectus eget hendrerit. Aenean lacinia volutpat blandit. In ultricies iaculis orci queleifend. Nunc in placerat odio. Nullam porta sapien ac nunc egestas aliquam. Nulla vitae pharetra enim. Sed sed consectetur nibh, vel placerat mauris.', 'chrisporate-pro' );
                   
                    // Push to the main array.
                    array_push( $content['detail'], $demo['detail'] );
                }

            break;

            case 'category':
                $cat_id = ! empty( $options['service_content_category'] ) ? $options['service_content_category'] : '';

                $args = array(
                    'post_type'         => 'post',
                    'cat'               => $cat_id,
                    'posts_per_page'    => $service_count,
                    );
            break;

            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $service_count; $i++ ) {
                    if ( ! empty( $options['service_content_page_' . $i] ) )
                        $page_ids[] = $options['service_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => $service_count,
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = ! empty( $options['service_content_post'] ) ? $options['service_content_post'] : array();
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => count( $post_ids ),
                    'orderby'           => 'post__in',
                    );
            break;

            default:
            break;
        }

        if ( in_array( $service_content_type, array( 'page', 'post', 'category' ) ) ) {

            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $icon_value = get_post_meta( get_the_id(), 'chrisporate-pro-post-icon', true );
                    $page_post['detail']['icon']        = ! empty( $icon_value ) ? $icon_value : 'fa-tint';
                    $page_post['detail']['id']          = get_the_id();
                    $page_post['detail']['title']       = get_the_title();
                    $page_post['detail']['sub_title']   = has_excerpt() ? get_the_excerpt() : '';
                    $page_post['detail']['excerpt']     = get_the_content();

                    // Push to the main array.
                    array_push( $content['detail'], $page_post['detail'] );
                endwhile;
            endif;
            wp_reset_postdata();

        }
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// service section content details.
add_filter( 'chrisporate_pro_filter_service_section_details', 'chrisporate_pro_get_service_section_details' );


if ( ! function_exists( 'chrisporate_pro_render_service_section' ) ) :
  /**
   * Start service section
   *
   * @return string service content
   * @since Chrisporate Pro 1.0.0
   *
   */
   function chrisporate_pro_render_service_section( $content_details = array() ) {
        $options = chrisporate_pro_get_theme_options();

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="services" class="page-section relative">
            <div class="container">
                <?php foreach ( $content_details['heading'] as $content ) : ?>
                    <div class="services-content-title clear">
                        <?php if ( ! empty( $content['title'] ) ) : ?>
                            <header class="entry-header section-title">
                                <h2 class="entry-title"><?php echo esc_html( $content['title'] ); ?></h2>
                            </header><!-- .entry-header -->
                        <?php endif; 

                        if ( ! empty( $content['excerpt'] ) ) : ?>
                            <p class="description"><?php echo wp_kses_post( $content['excerpt'] ); ?></p>
                        <?php endif; ?>
                    </div><!-- .services-contennt -->
                <?php endforeach; ?>

                <div class="entry-content">
                    <div class="tabs-wrapper">
                        <ul class="nav-tabs">
                            <?php $i = 1;
                            foreach ( $content_details['detail'] as $content ) : ?>
                                <li <?php echo ( $i == 1 ) ? 'class="active"' : ''; ?>>
                                    <a href="#<?php echo absint( $content['id'] ); ?>">
                                        <i class="fa <?php echo esc_attr( $content['icon'] ); ?>"></i>
                                        <h6><?php echo esc_html( $content['title'] ); ?></h6>
                                        <span><?php echo $i; ?></span>
                                    </a> 
                                </li>
                                <?php $i++; 
                            endforeach; ?>
                        </ul><!-- .nav-tabs -->

                        <div class="tabs-contents-wrapper">
                            <?php $i = 1; 
                            foreach( $content_details['detail'] as $content ) : 
                                $class = ( $i == 1 ) ? 'active' : '';
                                $class .= ! empty( $content['sub_title'] ) ? ' col-2' : ' col-1';
                                ?>
                                <div id="<?php echo absint( $content['id'] ); ?>" class="tab-pane <?php echo esc_attr( $class ); ?>">
                                    <?php if ( ! empty( $content['sub_title'] ) ) : ?>
                                        <strong class="pull-left"><?php echo esc_html( $content['sub_title'] ); ?></strong>
                                    <?php endif; ?>

                                    <div class="entry-summary pull-right">
                                        <p><?php echo wp_kses_post( $content['excerpt'] ); ?></p>
                                    </div><!-- .entry-summary -->
                                </div><!-- .tab-pane -->
                                <?php $i++;
                            endforeach; ?>
                        </div><!-- .tabs-contents-wrapper -->
                    </div><!-- .tabs-wrapper -->
                </div><!-- .entry-content -->
            </div><!-- .container -->
        </div><!-- #services -->
    <?php 
    }
endif;