<?php
/**
 * Subscription section
 *
 * This is the template for the content of subscription section
 *
 * @package Theme Palace
 * @subpackage Chrisporate Pro
 * @since Chrisporate Pro 1.0.0
 */
if ( ! function_exists( 'chrisporate_pro_add_subscription_section' ) ) :
    /**
    * Add subscription section
    *
    *@since Chrisporate Pro 1.0.0
    */
    function chrisporate_pro_add_subscription_section() {
        $options = chrisporate_pro_get_theme_options();
        // Check if subscription is enabled on frontpage
        $subscription_enable = apply_filters( 'chrisporate_pro_section_status', true, 'subscription_section_enable' );

        if ( true !== $subscription_enable ) {
            return false;
        }
        // Render subscription section now.
        chrisporate_pro_render_subscription_section();
    }
endif;
add_action( 'chrisporate_pro_footer_content', 'chrisporate_pro_add_subscription_section', 30 );

if ( ! function_exists( 'chrisporate_pro_render_subscription_section' ) ) :
  /**
   * Start subscription section
   *
   * @return string subscription content
   * @since Chrisporate Pro 1.0.0
   *
   */
   function chrisporate_pro_render_subscription_section() {
        $options = chrisporate_pro_get_theme_options();
        $title      = ! empty( $options['subscription_title'] ) ? $options['subscription_title'] : '';

        if ( ! class_exists( 'Jetpack' ) ) {
            return;
        } elseif ( class_exists( 'Jetpack' ) ) {
            if ( ! Jetpack::is_module_active( 'subscriptions' ) )
                return;
        } ?>
        <div id="subscribe" class="page-section relative">
            <div class="container">
                <?php 
                $subscription_shortcode = '[jetpack_subscription_form title="' . esc_html( $title ) . '" subscribe_text="" subscribe_button="' . esc_html__( 'Subscribe', 'chrisporate-pro' ) . '" show_subscribers_total="1"]';
                echo do_shortcode( wp_kses_post( $subscription_shortcode ) ); 
                ?>
            </div><!-- .container -->
        </div><!-- #subscribe -->
    <?php
    }
endif;