<?php
/**
 * Team section
 *
 * This is the template for the content of team section
 *
 * @package Theme Palace
 * @subpackage Chrisporate Pro
 * @since Chrisporate Pro 1.0.0
 */
if ( ! function_exists( 'chrisporate_pro_add_team_section' ) ) :
    /**
    * Add team section
    *
    *@since Chrisporate Pro 1.0.0
    */
    function chrisporate_pro_add_team_section() {
    	$options = chrisporate_pro_get_theme_options();
        // Check if team is enabled on frontpage
        $team_enable = apply_filters( 'chrisporate_pro_section_status', true, 'team_section_enable' );

        if ( true !== $team_enable ) {
            return false;
        }
        // Get team section details
        $section_details = array();
        $section_details = apply_filters( 'chrisporate_pro_filter_team_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render team section now.
        chrisporate_pro_render_team_section( $section_details );
    }
endif;


if ( ! function_exists( 'chrisporate_pro_get_team_section_details' ) ) :
    /**
    * team section details.
    *
    * @since Chrisporate Pro 1.0.0
    * @param array $input team section details.
    */
    function chrisporate_pro_get_team_section_details( $input ) {
        $options = chrisporate_pro_get_theme_options();

        // Content type.
        $team_title_type     = $options['team_title_type'];
        $team_content_type   = $options['team_content_type'];
        $content = array();
        $content['heading'] = array();
        $content['detail'] = array();
        switch ( $team_title_type ) {
            case 'demo':
                $demo['heading']['title']      = esc_html__( 'Our Team', 'chrisporate-pro' );
                $demo['heading']['excerpt']    = esc_html__( 'MCras placerat ipsum sit amet vehicula rhoncus. Aenean blandit leo mauris, ut lobortis diam egestas et. Pellentesque lorem massa, pharetra non dolor eu, pharetra maximus mi. Maecenas et condimentum erat. Donec consectetur neque justo, in faucibus nunc tristique sit amet.', 'chrisporate-pro' );

                // Push to the main array.
                array_push( $content['heading'], $demo['heading'] );
            break;

            case 'custom':
                $custom['heading']['title']        = ! empty( $options['team_title'] ) ? $options['team_title'] : '';
                $custom['heading']['excerpt']      = ! empty( $options['team_description'] ) ? $options['team_description'] : '';

                // Push to the main array.
                array_push( $content['heading'], $custom['heading'] );
            break;

            case 'page':
                $page_id = ! empty( $options['team_title_page'] ) ? $options['team_title_page'] : '';
                $args = array(
                    'post_type'         => 'page',
                    'page_id'           => $page_id,
                    'posts_per_page'    => 1,
                    );                    
            break;

            case 'post':
                $post_id = ! empty( $options['team_title_post'] ) ? $options['team_title_post'] : '';
                $args = array(
                    'post_type'           => 'post',
                    'p'                   => $post_id,
                    'posts_per_page'      => 1,
                    );
            break;

            default:
            break;
        }

        if ( 'post' === $team_title_type || 'page' === $team_title_type ) {

            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['heading']['title']     = get_the_title();
                    $page_post['heading']['excerpt']   = get_the_content();

                    // Push to the main array.
                    array_push( $content['heading'], $page_post['heading'] );
                endwhile;
            endif;
            wp_reset_postdata();

        }

        switch ( $team_content_type ) {
            case 'demo':
                $title = array(
                    1 => esc_html__( 'James Handerson', 'chrisporate-pro' ),
                    2 => esc_html__( 'Annie Nunes', 'chrisporate-pro' ),
                    3 => esc_html__( 'Helga Markus', 'chrisporate-pro' ),
                    );
                $sub_title = array(
                    1 => esc_html__( 'Designer', 'chrisporate-pro' ),
                    2 => esc_html__( 'Developer', 'chrisporate-pro' ),
                    3 => esc_html__( 'Photographer', 'chrisporate-pro' ),
                    );
                for ( $i = 1; $i <= 3; $i++ ) {
                    $demo['detail']['image']        = get_template_directory_uri() . '/assets/uploads/team-0' . $i . '.jpg';
                    $demo['detail']['title']        = $title[$i];
                    $demo['detail']['sub_title']    = $sub_title[$i];
                    $demo['detail']['id']           = 'team' . $i;
                    $demo['detail']['quote']        = sprintf( esc_html__( 'Hello, I am %s. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Phasellus ac felis risus.', 'chrisporate-pro' ), $title[$i] );
                    $demo['detail']['excerpt']      = esc_html__( 'Mauris ut metus a nibh fermentum mollis. Cras ullamcorper ac lectus eget hendrerit. Aenean lacinia volutpat blandit. In ultricies iaculis orci queleifend. Nunc in placerat odio. Nullam porta sapien ac nunc egestas aliquam. Nulla vitae pharetra enim. Sed sed consectetur nibh, vel placerat mauris. Mauris ut metus a nibh fermentum mollis. Cras ullamcorper ac lectus eget hendrerit. Aenean lacinia volutpat blandit. In ultricies iaculis orci queleifend. Nunc in placerat odio. Nullam porta sapien ac nunc egestas aliquam. Nulla vitae pharetra enim. Sed sed consectetur nibh, vel placerat mauris.', 'chrisporate-pro' );
                   
                    // Push to the main array.
                    array_push( $content['detail'], $demo['detail'] );
                }

            break;

            case 'custom':
                for ( $i = 1; $i <= 3; $i++ ) {
                    $custom['detail']['image']        = isset( $options['team_image_' . $i] ) ? $options['team_image_' . $i] : get_template_directory_uri() . '/assets/uploads/no-featured-image-353x469.jpg';
                    $custom['detail']['title']        = isset( $options['team_title_' . $i] ) ? $options['team_title_' . $i] : $options['team_title'];
                    $custom['detail']['sub_title']    = isset( $options['team_sub_title_' . $i] ) ? $options['team_sub_title_' . $i] : $options['team_sub_title'];
                    $custom['detail']['id']           = 'team' . $i;
                    $custom['detail']['quote']        = isset( $options['team_quote_' . $i] ) ? $options['team_quote_' . $i] : $options['team_quote'];
                    $custom['detail']['excerpt']      = isset( $options['team_description_' . $i] ) ? $options['team_description_' . $i] : $options['team_description'];
                   
                    // Push to the main array.
                    array_push( $content['detail'], $custom['detail'] );
                }

            break;

            case 'category':
                $cat_id = ! empty( $options['team_content_category'] ) ? $options['team_content_category'] : '';

                $args = array(
                    'post_type'         => 'post',
                    'cat'               => $cat_id,
                    'posts_per_page'    => 3,
                    'ignore_sticky_posts' => true,
                    );
            break;

            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= 3; $i++ ) {
                    if ( ! empty( $options['team_content_page_' . $i] ) )
                        $page_ids[] = $options['team_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => 3,
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = ! empty( $options['team_content_post'] ) ? $options['team_content_post'] : array();
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => 3,
                    'ignore_sticky_posts' => true,
                    'orderby'           => 'post__in',
                    );
            break;

            default:
            break;
        }

        if ( in_array( $team_content_type, array( 'page', 'post', 'category' ) ) ) {

            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['detail']['image']       = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'chrisporate-pro-medium' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-353x469.jpg';
                    $page_post['detail']['title']       = get_the_title();
                    $page_post['detail']['subtitle']    = '';
                    $page_post['detail']['id']          = 'team' . get_the_id();
                    $page_post['detail']['quote']       = has_excerpt() ? get_the_excerpt() : '';;
                    $page_post['detail']['excerpt']     = get_the_content();

                    // Push to the main array.
                    array_push( $content['detail'], $page_post['detail'] );
                endwhile;
            endif;
            wp_reset_postdata();

        }
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// team section content details.
add_filter( 'chrisporate_pro_filter_team_section_details', 'chrisporate_pro_get_team_section_details' );


if ( ! function_exists( 'chrisporate_pro_render_team_section' ) ) :
  /**
   * Start team section
   *
   * @return string team content
   * @since Chrisporate Pro 1.0.0
   *
   */
   function chrisporate_pro_render_team_section( $content_details = array() ) {
        $options = chrisporate_pro_get_theme_options();

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="team" class="page-section col-<?php echo count($content_details['detail']); ?> relative">
            <div class="container">
                <?php foreach ( $content_details['heading'] as $content ) : ?>
                    <div class="team-content-title clear">
                        <?php if ( ! empty( $content['title'] ) ) : ?>
                            <header class="entry-header section-title">
                                <h2 class="entry-title"><?php echo esc_html( $content['title'] ); ?></h2>
                            </header><!-- .entry-header -->
                        <?php endif; 
                        if ( ! empty( $content['excerpt'] ) ) : ?>
                            <p class="description"><?php echo wp_kses_post( $content['excerpt'] ); ?></p>
                        <?php endif; ?>
                    </div><!-- team-content -->
                <?php endforeach; ?>

                <div class="entry-content">
                    <div class="tabs-wrapper">
                       <ul class="nav-tabs">
                            <?php $i = 1;
                            foreach ( $content_details['detail'] as $content ) : ?>
                                <li <?php echo ( 1 === $i ) ? 'class="active"' : ''; ?>>
                                    <a href="#<?php echo esc_attr( $content['id'] ); ?>">
                                        <img src="<?php echo esc_url( $content['image'] ); ?>" alt="<?php echo esc_attr( $content['title'] ); ?>">
                                        <?php if ( ! empty( $content['title'] ) ) : ?>
                                            <h4><?php echo esc_html( $content['title'] ); ?></h4>
                                        <?php endif; 
                                        if ( ! empty( $content['sub_title'] ) ) : ?>
                                            <span><?php echo esc_html( $content['sub_title'] ); ?></span>
                                        <?php endif; ?>
                                    </a>
                                </li>
                            <?php $i++;
                            endforeach; ?>
                        </ul><!-- .nav-tabs -->

                        <div class="tabs-contents-wrapper">
                            <?php $i = 1;
                            foreach ( $content_details['detail'] as $content ) : 
                                $class = ! empty( $content['quote'] ) ? 'col-2' : 'col-1'; 
                                $class .= ( 1 === $i ) ? ' active' : '';
                                ?>
                                <div id="<?php echo esc_attr( $content['id'] ); ?>" class="tab-pane <?php echo esc_attr( $class ); ?>">
                                    <?php if ( ! empty( $content['quote'] ) ) : ?>
                                        <strong class="pull-left"><?php echo esc_html( $content['quote'] ); ?></strong>
                                    <?php endif; 

                                    if ( ! empty( $content['excerpt'] ) ) : ?>
                                        <div class="entry-summary pull-right">
                                            <p><?php echo wp_kses_post( $content['excerpt'] ); ?></p>
                                        </div><!-- .entry-summary -->
                                    <?php endif; ?>
                                </div><!-- .tab-pane -->
                            <?php $i++;
                            endforeach; ?>
                        </div><!-- .tabs-contents-wrapper -->
                    </div><!-- .tabs-wrapper -->
                </div><!-- .entry-content -->
            </div><!-- .container --> 
        </div><!-- #team -->
    <?php 
    }
endif;